PrimitiveUnsignedRef

Trait PrimitiveUnsignedRef 

pub trait PrimitiveUnsignedRef<T>: PrimitiveIntegerRef<T> { }
Trait for references to primitive unsigned integer types (PrimitiveUnsigned).

This enables traits like the standard operators in generic code, e.g. where &T: PrimitiveUnsignedRef<T>.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PrimitiveUnsignedRef<u8> for &u8

Source

impl PrimitiveUnsignedRef<u16> for &u16

Source

impl PrimitiveUnsignedRef<u32> for &u32

Source

impl PrimitiveUnsignedRef<u64> for &u64

Source

impl PrimitiveUnsignedRef<u128> for &u128

Source

impl PrimitiveUnsignedRef<usize> for &usize

Implementors